Crate osh_dir_std

source ·

Re-exports

Modules

Structs

  • Indicates which relative paths of all dirs and files in a project are covered by what parts of a specific dir standard.

Constants

Functions

  • Given a set of ratings, filters out the one with the higest factor. If multiple have the same, highest factor, the first one is returned.
  • Given a set of the relative paths of all dirs and files in a project, for each of the known dir standards from https://github.com/hoijui/osh-dir-std/, calculate what record of the standard each dir or file might be covered under.
  • Given a set of the relative paths of all dirs and files in a project, for each of the known dir standards from https://github.com/hoijui/osh-dir-std/, calculate how likely it seems that the project is following this standard, and then only return the coverage for the best fit.
  • Given a set of the relative paths of all dirs and files in a project, for the given directory standard, calculate what record of the standard each dir or file might be covered under.
  • Given a set of the relative paths of all dirs and files in a project, for each of the known dir standards from https://github.com/hoijui/osh-dir-std/, calculate how likely it seems that the project is following this standard.
  • Given a set of the relative paths of all dirs and files in a project, for each of the known dir standards from https://github.com/hoijui/osh-dir-std/, calculate how likely it seems that the project is following this standard, and then only return the rating for the best fit.
  • Given a set of the relative paths of all dirs and files in a project, for the given directory standard, calculate how likely it seems that the project is following this standard.